# supress missing import _version as that file is autogenerated by `hatch build --hooks-only`
# pyright: reportMissingImports=false
from importlib import metadata

try:
    from ._version import __version__
except ImportError:
    try:
        __version__ = metadata.version("aicage")
    except metadata.PackageNotFoundError:
        __version__ = "0.0.0"
